package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````>!8``#0```"LD`````0`!30`(``'
M`"@`&P`:``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````[(H`
M`.R*```%```````!``$```#LB@``[(H!`.R*`0"H`@``&`<```8```````$`
M`@```/B*``#XB@$`^(H!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&2TA```M(0``+2$``#T````]`````0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$``#`K](U!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-FAF`````&$```!I```````````````Q````#@``````````
M````.`````\```!``````````#```````````P```$X```!A`````````!\`
M``!-````!@```!T````4`````````$,```!7````70`````````7````/```
M`%@```!B`````````&4```!G````+P```!(`````````10```!4```!<````
M1P````````!*````1@```#4```!;````)0```"H`````````!P```$\`````
M````#````"P```!H````6@```$P````@````4````&8`````````7P``````
M```8````+@```$$````````````````````1````,P`````````)````8```
M`%$````````````````````C````.0````````!2````!0```$@````;````
M.P````````````````````````!+`````````#H```!4````8P````````!D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````$P``````````````
M`````````````````````````````````````"(````A`````````"D`````
M````"@```"<````H````+0``````````````#0````L````<````&@```!D`
M`````````````!``````````-````#(````W````'@``````````````````
M````````````!````````````````````$(````D````````````````````
M%@`````````_````1````"L````(```````````````^``````````````!6
M````)@`````````]``````````````!3`````````$D`````````````````
M``!5````60```#8```!>````````````````````````````````````>!8`
M```````#``L``````/2*`0```````P`1`)<``````````````!(````,````
M```````````2````%```````````````$@```'D#``#<(```"````!(`"P`<
M```````````````B````*P``````````````$@```#$``````````````!(`
M``"*`P``E(T!```````0`!4`.```````````````$@```#X`````````````
M`!(```"8`P``N"<``"`````2``L`10``````````````$@```$\#````````
M`````!(```"S`P``&#,``&@````2``L`B```````````````$@```,<#```$
MD@$``````!``%0!-```````````````2````OP,``)2-`0``````$``4`%T`
M`````````````!(```!L```````````````2````<@``````````````$@``
M`'D``````````````!(```"#```````````````2````C0``````````````
M$@```,8#```$D@$``````!``%0"6```````````````2````1P,`````````
M````$@```)P``````````````!(```"C```````````````2````L0``````
M````````$@```,(``````````````!$```#/```````````````2````T@,`
M`&0C```H````$@`+`-\#``",(P``5`$``!(`"P#K`P``S"@``+@'```2``L`
M"@,`````````````$@```-T``````````````!8```#P```````````````2
M````80,`````````````$@```/L``````````````!(````$`0```)(!``0`
M```1`!4`#`$`````````````$@```!4!`````````````!(````]`P``````
M```````2````(0$`````````````$@```"@!`````````````!(```#X`P``
MX#\``!@!```2``L`.P$`````````````$0```$T!`````````````!(```!=
M`0`````````````2````:P$`````````````$@```'`!`````````````!(`
M```#!```D(T!``0````1`!0`?P$`````````````$@```(L!````````````
M`!(```"@`0`````````````2````JP$`````````````$@```'0#```$D@$`
M`````!``%0#I`@`````````````2````O@$`````````````$@```$8$``!X
M%@```````!(`"P#,`0`````````````2````U`$`````````````(@```.P!
M`````````````!(```#X`0`````````````2````#00```22`0``````$``5
M`!4$``#@)```,`(``!(`"P#^`0`````````````B````%`(`````````````
M$@```!\"`````````````!(````B!```^$```'@!```2``L`,`(`````````
M````$@```"P$``"4C0$``````!``%0`X!```_!\``&@````2``L`0`0``$Q#
M``!\`@``$@`+`#<"`````````````!(```!%!```>!8````````2``L`/@(`
M````````````$@```$4"`````````````!(```!-!```Y"```(`"```2``L`
M6@0``-@G``#T````$@`+`&P$```0)P``J````!(`"P!<`@`````````````2
M````^`(`````````````$@```&T"`````````````!(```!\`@``````````
M```2````A0(`````````````$@```(L"`````````````!(````P`P``````
M```````2````D`(`````````````$@```",#``#$C0$`!````!$`%0"8`@``
M```````````2````5@,`````````````$@```)\"`````````````!(```!Z
M!```@#\``&`````2``L`I@(`````````````$@```+4"`````````````!$`
M```8`P``5(T!``0````1`!0`@P0``(0P``"4`@``$@`+`#0!````````````
M`!(```"Z`@`````````````2````:`,`````````````$@````!L:6)P97)L
M+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA;&EZ90!R;61I<@!S=')S
M='(`8VQO<V4`<W1R8VAR`'-T<FYC;7``8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M8V]N<W1R=6-T`&%B;W)T`'5N;&EN:P!?7VQS=&%T-3``<&5R;%]F<F5E`%]?
M<W1A=#4P`%]E>&ET`&UE;6-P>0!P97)L7V1E<W1R=6-T`%]?<W1A8VM?8VAK
M7V9A:6P`4$Q?9&]?=6YD=6UP`%!E<FQ?<W9?<V5T<'8`4$Q?8W5R<F5N=%]C
M;VYT97AT`'!E<FQ?86QL;V,`8VQO<V5D:7(`96YV:7)O;@!R96%D;&EN:P!?
M7V]P96YD:7(S,`!M96US970`4&5R;%]S869E<WES;6%L;&]C`%]?<W1A8VM?
M8VAK7V=U87)D`%!E<FQ?9W9?9F5T8VAP=@!?7W-P<FEN=&9?8VAK`')E860`
M4&5R;%]S>7-?:6YI=#,`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]N97=84P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R
M;0!?7V5R<FYO`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`%!E<FQ?;6=?<V5T
M`&UK9&ER`%]?<F5G:7-T97)?9G)A;65?:6YF;P!P97)L7W!A<G-E`%!E<FQ?
M;F5W6%-?9FQA9W,`86-C97-S`&=E='!I9`!M96UC:'(`4&5R;%]C<F]A:U]M
M96UO<GE?=W)A<`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<W9?<V5T<'9N`'!E
M<FQ?<G5N`&QS965K`&]P96X`<W!R:6YT9@!G971U:60`<W1R;&5N`%]?=&QS
M7V=E=%]A9&1R`%]?<T8`<W1R8VUP`&QI8FTN<V\N,`!L:6)C<GEP="YS;RXQ
M`&QI8G!T:')E860N<V\N,0!P=&AR96%D7V%T9F]R:P!S=')D=7``;&EB8RYS
M;RXQ,@!?7W-T<FYC<'E?8VAK`%]?<')O9VYA;64`7U]P<U]S=')I;F=S`%]?
M9V5T<'=U:60U,`!?7W-Y<V-A;&P`9G!R:6YT9@!A=&5X:70`7VQI8F-?:6YI
M=`!S=')T;VL`7U]R96%D9&ER,S``7V5N9`!P87)?8W5R<F5N=%]E>&5C`%]?
M8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?9&ER
M;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!M>5]P87)?<&P`7U]E;F1?
M7P!P87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`
M;6%I;@!?7W-T87)T`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?96YV7V-L96%N`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5``O
M=7-R+W!K9R]L:6(O<&5R;#4O-2XS-BXP+V5A<FUV-FAF+6YE=&)S9"UT:')E
M860M;75L=&DO0T]213HO=7-R+W!K9R]L:6(```#LB@$`%P```/"*`0`7````
M_(P!`!<````$C0$`%P````R-`0`7````'(T!`!<````@C0$`%P```"B-`0`7
M````+(T!`!<````\C0$`%P```$2-`0`7````3(T!`!<```!0C0$`%P```%2-
M`0`7````6(T!`!<```!@C0$`%P```&2-`0`7````;(T!`!<```!PC0$`%P``
M`'2-`0`7````>(T!`!<```!\C0$`%P```(2-`0`7````B(T!`!<```"0C0$`
M%P````"-`0`5!P``"(T!`!43```0C0$`%2$``!2-`0`1)P``&(T!`!(G```D
MC0$`%3(``#"-`0`5.P``-(T!`!5!```XC0$`%48``$"-`0`550``2(T!`!5C
M``#TBP$`%@,``/B+`0`6!```_(L!`!8%````C`$`%@<```2,`0`6"```"(P!
M`!8)```,C`$`%@L``!",`0`6#```%(P!`!8.```8C`$`%@\``!R,`0`6$0``
M((P!`!85```DC`$`%A8``"B,`0`6%P``+(P!`!88```PC`$`%AD``#2,`0`6
M&@``.(P!`!8<```\C`$`%AT``$",`0`6'@``1(P!`!8?``!(C`$`%B```$R,
M`0`6(@``4(P!`!8F``!4C`$`%B@``%B,`0`6*0``7(P!`!8J``!@C`$`%BP`
M`&2,`0`6+0``:(P!`!8N``!LC`$`%B\``'",`0`6,```=(P!`!8S``!XC`$`
M%C0``'R,`0`6-0``@(P!`!8V``"$C`$`%C@``(B,`0`6.0``C(P!`!8Z``"0
MC`$`%CT``)2,`0`6/@``F(P!`!9```"<C`$`%D$``*",`0`60@``I(P!`!9#
M``"HC`$`%D8``*R,`0`61P``L(P!`!9(``"TC`$`%DH``+B,`0`63@``O(P!
M`!90``#`C`$`%E$``,2,`0`65@``R(P!`!97``#,C`$`%E@``-",`0`660``
MU(P!`!9:``#8C`$`%EL``-R,`0`67```X(P!`!9>``#DC`$`%E\``.B,`0`6
M8```[(P!`!9B``#PC`$`%F8``/2,`0`69P``^(P!`!9H```$X"WE!."?Y0[@
MC^`(\+[EC'@!``#&C^(7RHSBC/B\Y0#&C^(7RHSBA/B\Y0#&C^(7RHSB?/B\
MY0#&C^(7RHSB=/B\Y0#&C^(7RHSB;/B\Y0#&C^(7RHSB9/B\Y0#&C^(7RHSB
M7/B\Y0#&C^(7RHSB5/B\Y0#&C^(7RHSB3/B\Y0#&C^(7RHSB1/B\Y0#&C^(7
MRHSB//B\Y0#&C^(7RHSB-/B\Y0#&C^(7RHSB+/B\Y0#&C^(7RHSB)/B\Y0#&
MC^(7RHSB'/B\Y0#&C^(7RHSB%/B\Y0#&C^(7RHSB#/B\Y0#&C^(7RHSB!/B\
MY0#&C^(7RHSB_/>\Y0#&C^(7RHSB]/>\Y0#&C^(7RHSB[/>\Y0#&C^(7RHSB
MY/>\Y0#&C^(7RHSBW/>\Y0#&C^(7RHSBU/>\Y0#&C^(7RHSBS/>\Y0#&C^(7
MRHSBQ/>\Y0#&C^(7RHSBO/>\Y0#&C^(7RHSBM/>\Y0#&C^(7RHSBK/>\Y0#&
MC^(7RHSBI/>\Y0#&C^(7RHSBG/>\Y0#&C^(7RHSBE/>\Y0#&C^(7RHSBC/>\
MY0#&C^(7RHSBA/>\Y0#&C^(7RHSB?/>\Y0#&C^(7RHSB=/>\Y0#&C^(7RHSB
M;/>\Y0#&C^(7RHSB9/>\Y0#&C^(7RHSB7/>\Y0#&C^(7RHSB5/>\Y0#&C^(7
MRHSB3/>\Y0#&C^(7RHSB1/>\Y0#&C^(7RHSB//>\Y0#&C^(7RHSB-/>\Y0#&
MC^(7RHSB+/>\Y0#&C^(7RHSB)/>\Y0#&C^(7RHSB'/>\Y0#&C^(7RHSB%/>\
MY0#&C^(7RHSB#/>\Y0#&C^(7RHSB!/>\Y0#&C^(7RHSB_/:\Y0#&C^(7RHSB
M]/:\Y0#&C^(7RHSB[/:\Y0#&C^(7RHSBY/:\Y0#&C^(7RHSBW/:\Y0#&C^(7
MRHSBU/:\Y0#&C^(7RHSBS/:\Y0#&C^(7RHSBQ/:\Y0#&C^(7RHSBO/:\Y0#&
MC^(7RHSBM/:\Y0#&C^(7RHSBK/:\Y0#&C^(7RHSBI/:\Y0#&C^(7RHSBG/:\
MY0#&C^(7RHSBE/:\Y0#&C^(7RHSBC/:\Y0#&C^(7RHSBA/:\Y0`0H.$"`*#A
M!]#-XSD``.H-P*#A,-@MZ40@G^5$,)_E`B"/X$!`G^4#,)+G!$"/X`,`5.$$
ML$SB,*B=*`-0@^($,(3B`U!%X`-0Q>,#4(7@!#"4Y#/_+^$%`%3A^___&C"H
MG>A(=0$`%`$``$1T`0`-P*#A\-@MZ6P@G^5L$)_E;#"?Y0(@C^`!0)+G`S"2
MYP2P3.(#`%3A\*B=*`0@U.6@`%+C#P``&@A`A.('<(/B!'!'X`=PQ^,$<(?@
M"%`4Y01@H.$`,)7E,_\OX0<`5.$``(7E\*B="`0PUN4(0(3BH`!3X_3__PHB
M___KY'0!`#@!```<`0``#<"@X8#8+>EP@9_E!+!,X@S03>(`8%'B"("/X$L`
M``I<,9_E`""6Y0,0F.=4,9_E`,"2Y0!@@>4#<)CG"#"6Y0``7.,`,(?E.@``
M"C@QG^4#$)CG`,"!Y0`@DN4`,-+E``!3XP4```H!((+B+P!3XP`@@04!,-+D
M``!3X_K__QH``%#C````"O/^_^N+___K^#"?Y0,PF.<``%/C-0``"NPPG^7L
M0)_E`S"8YP1`C^`#`%3A"```*@-0@^($,(3B`U!%X`-0Q>,#4(7@!#"4Y#/_
M+^$%`%3A^___&K@`G^6X0)_E``"/X-O^_^NP,)_E!$"/X`,PF.<#`%3A"```
M*@-0@^($,(3B`U!%X`-0Q>,#4(7@!#"4Y#/_+^$$`%7A^___&@`@E^4`$);E
M!`"6Y:D*`.NM_O_K3""?Y60PG^4"()CG`S"/X``P@N7+___J$R"@XU`PG^4`
M((WE`S"/X`(@H.,$`*#C`!"@X_;^_^L!`*#CT/[_ZW[__^O'___J6'0!`%P!
M```T`0``9`$``%0!```D`0``R'(!`"S^__^$<@$`0`$```1U`0#T+```#<"@
MX=0PG^7PVRWI`(!0X@2P3.(!<*#A`S"/X"L```J\()_E`C"3YP"0D^4``%GC
M*```"@`PV.4]4%/B`5"@$P``4^,`4*`#``!5XQ$``!H`0)GE``!4XPP```H)
M8*#A!2"@X0@0H.$$`*#AB_[_ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``
M5./S__\:!`"@X?"KG>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F___J"6!&
MX`%0A>)&8:#A!4"$X`!@A^4$`*#A\*N=Z`A`H.'M___J"4"@X>O__^JH<@$`
M-`$```W`H.'PV"WI!+!,X@C03>(`4*#A@'"?Y8`PG^4'<(_@`V"7YR1`2^(`
M,);E(#`+Y000H.$%`*#AMO__ZP``4.,.```*6#"?Y200&^4#,)?G`""3Y0$Q
M@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J("`;
MY0`PEN4#`%+A`0``&AS02^+PJ)WH;?[_Z[QQ`0`\`0``-`$```W`H.'PWRWI
M!+!,XJS03>(T,9_E-"&?Y0,PC^`"0)/G`&!0X@`PE.4P,`OE`@``"@`PUN4`
M`%/C!0``&C`@&^4`,)3E`P!2X3X``!HHT$OB\*^=Z&G^_^L`<%#B]O__"NPP
MG^7L@)_E`S"/X.B0G^70,`OES#!+X@B`C^`)D(_@U#`+Y0<`H.'+_O_K``!0
MXR4```H-4(#B!0"@X0@0H.'"_O_K``!0X_7__PH)$*#A!0"@X;W^_^L``%#C
M\/__"@8`H.&P_O_K`*"@X04`H.&M_O_K``"*X`(`@.*P_O_K`*"@X04PH.$&
M(*#AT!`;Y9S^_^O4$!OE"@"@X1O^_^L!`'#C"@"@X0,```K$,!OE#SH#X@$)
M4^,(```*"O[_ZPH`H.'__?_KU?__Z@<`H.$L_O_K!@"@X>C]_^N^___JKO__
MZ_7__^H7_O_K&'$!`#P!``#T*@``W"H``-PJ```-P*#A\-\MZ02P3.(4T$WB
M`4"@X0R2G^4,,I_E`"#1Y0F0C^`#8)GG/0!2XP%`@0(`,);E`%"@X00`H.$P
M,`OE>?[_ZS002^(`<*#A!0"@X2[__^L`@%#B/@``"G+^_^L'`%#A-0``*L`Q
MG^4T@!OE`Y"9YPB!H.$`,-7E/0!3X@$`H!,``%/C``"@`P``4.,%```*!0"@
MX0$P\.4``%/C/0!3$_O__QH%`$#@`G"'X@``A^``<)GE8?[_ZP``4.,(`(?G
M5```"@`PU>4`()GE/0!3XP``4Q,T$!OE`0"%X@$1DN<`,,'E!@``"@$@@>(!
M,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C`2"@X0`PP>4!,-3D``!3XP$P
MXN7[__\:``"@XS`@&^4`,);E`P!2X3H``!HHT$OB\*^=Z`$P2.(!(-3D``!2
MXP$@X^7[__\:\O__ZM`PG^4#D)GG`""9Y0"@DN4``%KC"!"@`PD```H(,*#A
M`A"@X0```.H*,*#A!`"QY0&@@^(``%#C^O__&@,P@^(#$:#AD#"?Y0,PC^``
M`)/E``!0XQ,``!H!P*#C`0"@X0#`@^4\(`OE'_[_ZP`P4.(X,`OE$@``"CP@
M&^4*@:#A`A"@X0@@H.%@_?_K.#`;Y0`PB>4`$*#C`2"*X@(1@^<TH`OEG?__
MZ@(`H.%4_?_K``!0XP`PH.$``(GE"H&@$?/__QH``.#CP/__ZHC]_^NP;P$`
M/`$``#0!```X<`$`#<"@X3#8+>D$L$SBH-!-XG`PG^5P()_E`S"/X`)`D^>T
M$$OB`#"4Y0!0H.$8,`OE8OW_ZP``4.,``*`3!```&JPP&^4/.@/B"@I3XP$)
M4Q,%```*&"`;Y0`PE.4#`%+A!P``&A302^(PJ)WH!0"@X0(0H..W_?_K$`]O
MX:`"H.'S___J8OW_ZX!M`0`\`0``#<"@X?#;+>D$L$SB0=Y-XO0PG^5"SDOB
M",!,XNP@G^4#,(_@,,0+Y0)0D^<`<*#AW`"?Y0`PE>4!D*#AU""?Y0P0H.$`
M`(_@*#`+Y5[]_^L`@%#B(@``VKP`G^4!0$CB``"/X,']_^LD,$OB!#"#X`0T
M4^4`8)#E``!3XQ$```H(0*#A!""@X2\0H.,P!!OEDOW_ZP``4.,,```*!#"@
MX0<0H.$&`*#A,"0;Y93]_^LH(!OE`#"5Y0,`4N$1```:)-!+XO"KG>@``%3C
M[/__&@D@H.$'$*#A!@"@X2O]_^OR___J-`"?Y0``C^"?_?_K`&"0Y0D@H.$'
M$*#A!@"@X2+]_^OI___J'?W_Z^AL`0`\`0``^"8``/\#``#4;0$`3&T!``W`
MH.'PV"WI1""?Y40`G^5$,)_E!+!,X@(@C^```(_@.%"?Y3A`G^4#8)+GAOW_
MZP50C^`$0(_@!3"@X08@H.$$$*#A``"0Y1S02^+P:)WH-?W_ZLQK`0#T;`$`
M(`$``*@E``#X)0``#<"@X3#8+>E4`)_E"-!-X@2P3.(``(_@<?W_ZP!0H.$`
M`)#EV___ZP`0H.,T0)_E-#"?Y01`C^`#()3G+#"?Y0``E>4$$(WE)!"?Y0,P
MC^``,(WE`1"/X#3]_^L4T$OB,*B=Z)1L`0!(:P$`:`$``$@H``",)0````"@
MXQ[_+^$-P*#A\-\MZ4W>3>($L$SB!-!-XC`RG^4P(I_E`S"/X`(@D^<`0*#A
M$WU+XB`"G^4`,)+E#'!'X@%0H.$``(_@!!!'XN`D"^4P,`OE^OW_ZR\0H.,`
M8*#A!`"@X9O\_^L``%#C"P``"N@!G^4$$*#A``"/X*S^_^L$`*#AX#0;Y3`@
M&^4`,)/E`P!2X6T``!HHT$OB\*^=Z`0`H.$M_?_KM!&?Y0"`H.$!$(_@!0"@
MX;S\_^L`H%#BZO__"IPQG^6<D9_E`S"/X.0T"^64,9_E`S"/X.@T"^6,,9_E
M`S"/X-@T"^6$,9_E`S"/X-PT"^4`,-KE``!3XS0```H``%;C!```"@H0H.$&
M`*#A&OW_ZP``4.,V```*"@"@X0W]_^L!,$#B`Q#:YP,PBN`O`%'C!0``&@#`
MH.,`P,/E`2!SY0$`0.(O`%+C^O__"@$PB.(``(/@"0!0X<+__\K<-!OE0UY+
MX@0PC>4!*Z#CV#0;Y0`0H.,(0(WE`*"-Y04`H.&@_/_K!Q"@X04`H.%J_/_K
M``!0XP,``!K$-!OE#SH#X@()4^,8```*Q!"?Y0``H.,!$(_@>_S_ZP"@H.$`
M`%KCJ/__"@`PVN4``%/CRO__&@``5N,8```*Y!0;Y08`H.'E_/_K``!0X^2D
M&Q4!`*`3U?__&GP0G^4``*#C`1"/X&C\_^L`H*#AZ___Z@$0H.,%`*#AJ/S_
MZP``4./A__\:5`"?Y040H.$``(_@/O[_ZP4`H.&L_/_KC___ZNBD&^4!`*#C
MP/__ZDK\_^O@:@$`/`$``#PE```4)0``["0``%PD``#_`P``4"0``+PD``!<
M)P``Y",``)@C``!<(P```"#0Y0``4N,>_R\!`3"`XB\`4N,#`*`!`2#3Y```
M4N/Z__\:'O\OX0W`H.$PV"WI`$!0X@2P3.(<```*`%#4Y0``5>,9```*HOS_
MZP$`0.(`((3@`@!4X0L``"H`,-3G+P!3XRT``!H!,$+B`P``Z@`0T^4!,$/B
M+P!1XR<``!H$`%/A`R"@X?C__QH"`%3A"P``&B\`5>,N```*R`"?Y0``C^`4
MT$OB,&B=Z&[\_^JX`)_E``"/X!302^(P:)WH:?S_Z@$@0N($``#J`##2Y0$0
M0N(O`%/C`@``&@$@H.$"`%3A^/__.@0@0N`",(+B`0M3XQ4``(IT4)_E`2""
MX@50C^`$4(7B!!"@X04`H.$!.Z#C_?O_ZP4`H.$PJ)WH`3!"X@,``.H`$-/E
M`3!#XB\`4>/B__\*`P!4X0,@H.'X__\Z`@!4X='__PK<___J``"@XS"HG>@8
M`)_E``"/X!302^(P:)WH/_S_ZB0E``#L(0``A&D!`$0A```-P*#A<-@MZ02P
M3.(TT$WBM,&?Y;1!G^4,P(_@L%&?Y01`C^`,P(SB1.!+X@50E.</`+SH#P"N
MZ`\`O.@/`*[HD`&?Y0`@G.4`,)7E``"/X+`@SN$@,`OE,OW_ZW@!G^5X89_E
M``"/X"[]_^MP`9_E!F"/X```C^`J_?_K9`&?Y4A`2^(``(_@)OW_ZU@!G^4`
M`(_@(_W_ZU`!G^4``(_@(/W_ZT@!G^4``(_@'?W_ZT`!G^4``(_@&OW_ZP8`
MH.$8_?_K,`&?Y0``C^`5_?_K*`&?Y0``C^`2_?_K(`&?Y000H.$``(_@U/S_
MZP`04.(!```*!@"@X8S]_^L$`9_E!!"@X0``C^#,_/_K`!!0X@(```KP`)_E
M``"/X(/]_^OH`)_E!!"@X0``C^##_/_K`!!0X@T```K4`)_E``"/X'K]_^O,
M$)_ES`"?Y0$0C^```(_@=?W_ZR`@&^4`,)7E`P!2X1<``!H8T$OB<*B=Z*@`
MG^4$$*#A``"/X*_\_^L`$%#B"P``&I00G^4*(*#C`1"/X#,`2^)0^__K``!0
MX^?__QI\`)_E*1!+X@``C^!>_?_KXO__ZFP`G^4``(_@6OW_Z][__^IK^__K
MW"```.!F`0`\`0``6"$``$PA``"$(0``1"$``$`A```\(0``0"$``-0@```T
M(0``."$``+0@```H(0``'"$``!PA```8(0``0"```"0A``!\(```V"```-0@
M```\(```+"````W`H.$0V"WI!+!,X@S03>)\,)_E?!"?Y7P@G^4#,(_@`B"/
MX`%`D^<``)+E`""4Y0$`<.,8(`OE!0``"A@@&^4`,)3E`P!2X1```!H0T$OB
M$*B=Z$0`G^4<$$OB``"/X&K\_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,`
M`*`#'#"?Y0,PC^```(/EZO__ZBW[_^NT9`$`/`$``"1F`0!<'P``P&4!``W`
MH.$`V"WI!+!,XI;[_^N/^__K``!0XP``D!4`J)WH#<"@X?#9+>D$L$SB%-!-
MXL0PG^7$()_E`S"/X`)`D^>\8)_E`#"4Y09@C^``4*#A+!!+X@8`H.$H,`OE
M0?S_ZP!P4.(%$*#A&0``"@`PU^4``%/C%@``"MGZ_^L``%#C%@``&@4`H.%]
M^__K`("@X0<`H.%Z^__K``"(X`(`@.)]^__K`("@X5@PG^58$)_E`'"-Y04@
MH.$#,(_@`1"/X&;[_^L($*#A!@"@X>'\_^L"``#J-`"?Y0``C^#=_/_K*"`;
MY0`PE.4#`%+A`0``&B#02^+PJ9WHZ?K_Z_!C`0`\`0``5!\```@>```('@``
MQ!X```W`H.'PWRWI@=Q-X@2P3.(\T$WB(,>?Y8$L2^(<AY_E`FE+X@S`C^`L
M8$;B2"!"X@Q7G^4``(+E"("/X!$^1N(00(SB^.!&X@50F.<'`)SI!P"#Z`\`
MM.@/`*[H`P"4Z($\2^*!+$OB+"!"XH%\2^)4,$/B`""#Y2C`C.)!/T;B4'!'
MX@!`E>4`4(?E`P".Z!100N('`)SH!P"#Z*0&G^4%$*#A``"/X#!`"^7H^__K
M`$!0X@(```H`,-3E``!3XYL``!J(___K`*!0XIT```H*`*#A)?O_ZX``H.$!
M`(#B*/O_ZP`@VN6!/$OB3#!#X@``4N,``(/E"P``"H$\2^),,$/B0':?Y0!`
MD^4'<(_@!`"@X0<0H.$+^__K`2#ZY0)`A.(``%+C^/__&O@`%N4``%#C$@``
M"O1`1N("``#J!`"4Y```4.,-```*!1"@X;_[_^L`<%#B^/__"@`PU^4``%/C
M]?__"@/]_^L``%#C\O__"@<`H.'A^O_K`*!0XAH``!H`D*#C@3Q+XE0P0^(`
M,)/E$$!#X@DQAN`0<1/E``!7XPH```H`,-?E``!3XP<```H'`*#A[_S_ZP``
M4.,!D(GB!```&@EQE.<``%?C]/__&@"@H.,$``#J!P"@X<?Z_^L``%#CZO__
M"@"@H.$*`*#AW?K_ZX$\2^),,$/B`)"3Y0!PH.$)`*#AU_K_ZP``A^`!>X#B
M!'"'X@<`H.'8^O_K`$"@X2`UG^4@%9_E`S"/X``PC>48-9_E"B"@X0,PC^`!
M$(_@!)"-Y;[Z_^L$`*#A!QV@XY'Z_^L!`'#C'@``"N`01N($`*#A,OK_ZP"0
M4.(#```:V#`6Y0\Z`^(!"5/C2P``"LPDG^7,%)_E`@"8YX$L2^)(($+B`""2
MY00PH.$`()+EL`"`X@$0C^`M^O_K`'"@XX$\2^)0,$/B`#"3Y3`@&^4`,)/E
M!P"@X0,`4N$7`0`:*-!+XO"OG>AF^O_K`#"0Y1$`4^/<__\*@3Q+XD@P0^(`
M,)/E`'"@XP!0D^5=^O_K3#2?Y0`0D.4#`)CG`!"-Y404G^4%(*#A!#"@X;``
M@.(!$(_@#OK_Z^#__^KT_O_K!`"@X7#Z_^L`<*#AV___Z@IPH.&!3$OB,$!$
MX@<!E.<``%#C#```"@40H.$Z^__K`#!0X@%PA^+W__\*`##3Y0``4^/T__\*
M7_K_ZP``4./Q__\*`*"@X4[__^H-`*#C>OK_Z\2CG^6!/$OB3#!#X@``@^4*
MH(_@4R"@XU#__^K$H!;E9?K_ZP``6N&O__\:V#`6Y8,[H.&C.Z#A!PU3XZK_
M_QH'`*#A:/K_ZP!PH.%\`Y_E!1"@X0``C^`6^__K``!0XU0```J!/$OB2#!#
MX@`PD^4`4)/E._K_ZP`0H.$%`*#A_?S_ZP!04.)*```*!0"@X4_Z_^L#`%#C
M`("@X0P``)HL$Y_E!`!`X@``A>`!$(_@4/K_ZP``4.,%```:!`!8XX(```H(
M@(7@!3!8Y2\`4^-^```*<_[_ZP`04.(#```:!0"@X2OZ_^L`4%#B-@``&N`2
MG^7@`I_E`1"/X```C^"H^__K#OK_Z]`RG^70$I_E`S"/X`D`C>C(,I_ER(*?
MY<ABG^7(4I_E`S"/X`0@H.$!$(_@!P"@X1SZ_^L(@(_@!F"/X`50C^`,``#J
MY/G_ZP`PD.41`%/C#0``&OCY_^L!D(GB`0*-Z`A0C>4(,*#A!""@X080H.$'
M`*#A"_K_ZP<=H.,'`*#AWOG_ZP$`<./M__\*!`"@X73Y_^M4`I_E!Q"@X0``
MC^!^^__K!P"@X6[^_^M8___J@3Q+XD@P0^(`,)/E`%"3Y:___^H"D*#C`##@
MXQ$@X.,`D(WE!(!&XNGY_^L($*#A!B"@XP4`H.&F^?_K!#!6Y0``4^,"```:
M`S!6Y4,`4^-"```*`!"@XP`@H.,`,*#C`!"-Y04`H.'9^?_K.P0`ZP"0H.$"
M``#J"!"@X0D`H.%.!`#K`BF@XP@0H.$%`*#AD/G_ZP`@4.+V___*!0"@X410
M1N(W^?_K,(!&X@D0H.$%`*#AAP0`ZPB@H.&`D9_E"9"/X`$@U>0*`*#A"1"@
MX<CY_^L%`%CA`J"*XOC__QH``*#C7#&?Y5P1G^4#,(_@!#"-Y50QG^4`@(WE
M`S"/X`@`1N4$(*#A`1"/X`<`H.&X^?_KL/__ZH$\2^)(,$/B`#"3Y02`D^4`
M`%CC>O__"@@`H.&X^?_K`P!0XW;__YH,$9_E!`!`X@``B.`!$(_@NOG_ZP``
M4.,(4*`!;O__Z@(P5N5!`%/CN?__&@$P5N5#`%/CMO__&@`PUN5(`%/CL___
M&@$PUN5%`%/CL/__&@`PX.,`D(WE.2#@XP4`H.&+^?_K"!"@X04`H.$I(*#C
M2/G_ZYPPG^6<$)_E`S"/X`0PC>64,)_E`("-Y0,PC^`$(*#A`1"/X`<`H.&%
M^?_K??__ZA3Y_^MD9`$`W&(!`#P!``#L'```E!T``(0<``!D'```'!X``&`!
M``!,'```E!L``.P:``!<&P``#!L``/`9``!D&0``@!L``*@:``"8&P``A!L`
M`*@:``!,&P``4!@``(P8``#L&0``"!D```P:``"\&```'!D``#P8```\&0``
M#<"@X?#9+>D$L$SB#-!-XC`RG^4P(I_E`S"/X`)0D^<H`I_E`""5Y0``C^`H
M(`OE8_G_ZP`PD.44`I_E9"#3Y2Q@2^(&$*#A``"/X&4@P^41^O_K``!0XP(`
M``H`,-#E,0!3XUX```K[_/_KY`&?Y>1!G^4``(_@4?G_ZP1`C^`$$*#A`'"@
MX0,PH.,``)#E`2"@X_#X_^L`0%#B"@``"@PPE.6T(9_E`!"3Y0(@C^```)?E
MROC_ZPPPE.4`$)/E"#"1Y0$%$^-1```:D`&?Y9!!G^4``(_@.?G_ZP1`C^`$
M$*#A`'"@X0,PH.,``)#E`2"@X]CX_^L`0%#B"0``"F0!G^4&$*#A``"/X.+Y
M_^L`(%#B-@``"@PPE.4``)?E`!"3Y:[X_^M``9_E0(&?Y0``C^`B^?_K.!&?
MY0!PD.4`0*#A`2"@XP$0C^`'`*#AS?C_ZR`AG^4`$*#A`B"/X`<`H.&>^/_K
M`""@XP`PE.4(`9_E!A"@X64@P^4``(_@Q?G_ZPB`C^```%#C"`2(Y0L```H'
M':#CT_C_ZP$P@.(1`%#C`0!3$QT``(HH(!OE`#"5Y0,`4N$8```:(-!+XO"I
MG>@$!)CEGOW_ZP``4.,(!(CE[O__&J0`G^4``(_@K/C_ZP$PT.4``%/CGO__
M"IS__^J,,)_E#""4Y0,PC^`$-)/E``"2Y0`0D^40^__KQ/__Z@``E^6P^/_K
MJO__ZFSX_^M@()_E`#"@X0(@C^`$%)+E5`"?Y0@DDN4`$)'E``"/X)/X_^M$
M6P$`/`$``&!<`0#@%0``%%P!`&07```X%P``M%L!`!`7``#<%```6%L!`.!;
M`0"H%@``K!8``%P4```T%@``:%L!`#A;`0#T%0``#<"@X3#8+>D$L$SB`$"@
MX1?\_^L,_/_K`%"@X?7\_^L``%#C``!4$S"HG0@`,-3E``!3XS"HG0@D$)_E
M!0"@X00@H.,!$(_@%OC_ZP``4.,PJ)T8!`"@X1302^(P:)WHS/G_ZB04```-
MP*#A\-\MZ02P3.)5WTWBT#N?Y=#KG^4#,(_@#N"3YUW/2^(.0*#A#!"@X0!`
ME.5XX0OE'""`XES@@.(P0`OE!#"2Y#,_O^8"`%[A!#"AY?K__QITX$OB.#"<
MY21`G.4,$)SE!#`CX`0@O.4!,"/@`C`CX.,_H.$.`%SA0#",Y?3__QH$$)#E
M8#N?Y0C`D.5P(1OE`$"0Y6%AH.$0@)#E;!$;Y0S@D.4&4"S@`R""X`@@@N`$
M4`7@!("0Y0,0@>`.<"S@#%`EX`X0@>`!D(7@"'`'X&@1&^5D@:#A#G`GX.0M
M@N`'((+@9*$;Y0-P@>`($";@8E&@X0(0`>`,<(?@XBV)X`.@BN`%D"C@!A`A
MX`<0@>`&8(K@8G&@X0*0">!@H1OEXBV!X`B0*>`'$"7@!I")X`.@BN`"$`'@
M8F&@X>*=B>`(H(K@!2`AX%P1&^4&@"?@"B""X.DM@N`#H('@"8`(X&D1H.%8
MD1OE!X`HX`6@BN`!4";@"J"(X`.0B>`"@`7@!Y")X`:`*.!B4:#AXBV*X`F@
MB.!4@1OE!7`AX`.0B.`"@`?@!I")X`&`*.!B<:#AXBV*X`F@B.!0@1OE!V`E
MX`.0B.`"@`;@`9")X`6`*.!B8:#AXBV*X`F@B.!,@1OE!A`GX`.0B.`"@`'@
M!9")X`>`*.!B$:#AXBV*X`F@B.!(@1OE`5`FX`.0B.`"@`7@!Y")X`:`*.!B
M4:#AXBV*X`F@B.!$@1OE!7`AX`.0B.`"<`?@!I")X`%P)^!B@:#AXBV*X`F@
MA^!`<1OE"&`EX`.0A^`"<`;@8F&@X05P)^#B+8K@`1")X#RA&^4&D"C@`1"'
MX`*0">!B<:#A`Z"*X.(M@>`($"G@.)$;Y06@BN`'4";@"A"!X`.@B>`"D`7@
M"("*X`:@*>!B4:#A"*"*X#2!&^7B'8'@!2`GX`.0B.`!(`+@88&@X>&MBN`&
M8(G@!Q`BX`80@>`P81OE""`EX`.0AN#J'8'@:F&@X0H@`N`LH1OE!W")X`4@
M(N`&D"C@!R""X`&0">`#<(K@**$;Y>$M@N`%4(?@81&@X0B0*>`#H(K@!9")
MX`%0)N!B<:#AXIV)X`)0!>`(((K@)*$;Y0>`(>`&4"7@"8`(X`)0A>`#,(K@
ME"B?Y2"A&^4&,(/@`6`HX&F!H.'IG87@`U"&X`)@BN`(,"?@'*$;Y0$0AN`)
M8"/@:3&@X>E=A>`&8('@&)$;Y0(0BN`#H"C@!:`JX`<0@>!E<:#AY6V&X`H0
M@>`"4(G@%*$;Y0>0(^`&D"G@"%"%X&:!H.'F'8'@"5"%X`*@BN`(D"?@X6V%
MX`,PBN`!4"G@!5"#X!`Q&^5A$:#A#)$;Y0*@@^`!,"C@!Z"*X`8P(^!F<:#A
MYEV%X`,PBN`"8(G@"*$;Y0>0(>`%D"G@"&"&X&6!H.'E/8/@"6"&X`A0)^`"
MD(K@!*$;Y>-MAN`!$(G@`U`EX&,QH.$`D1OE!5"!X`*@BN`#$"C@!Z"*X`80
M(>!F<:#AYEV%X`$0BN`"8(G@_*`;Y0>0(^`%D"G@"&"&X&6!H.'E'8'@"6"&
MX`A0)^`"D(K@^*`;Y>%MAN`#,(G@`5`EX&$1H.'TD!OE!5"#X`*@BN`!,"C@
M!Z"*X`8P(^!F<:#AYEV%X`,PBN`"8(G@\*`;Y0>0(>`%D"G@"&"&X&6!H.'E
M/8/@"6"&X`A0)^`"D(K@[*`;Y>-MAN`!$(G@`U`EX&,QH.'HD!OE!5"!X`*@
MBN`#$"C@!Z"*X`80(>!F<:#AYEV%X`$0BN`"8(G@Y*`;Y0>0(^`(8(;@!8`I
MX&61H.'E'8'@"("&X`)@BN`)H"?@`S"&X`%@*N`&8(/@X#`;Y>%=B.!A$:#A
MW(`;Y0*@@^`!,"G@!Z"*X`4P(^!E<:#AY6V&X`,PBN`"4(C@V*`;Y0>`(>`)
M4(7@!H`HX&:1H.$"H(K@YFV#X`B`A>`),"?@U%`;Y>:-B.`!$(K@!C`CX&9A
MH.$"H(7@`S"!X`80*>!H4:#AZ"V#X`=PBN`!@"C@!#:?Y0B@A^#0<!OE!1"&
MX0.`A^`"$`'@8G&@X>(MBN`%H`;@"9"(X`J@@>',$!OE!X"%X0F@BN`"@`C@
M`Y"!X&(1H.'B+8K@!Z`%X`9@B>`*H(CAR)`;Y0&`A^$&H(K@`Y")X&)AH.$"
M@`C@XBV*X`&@!^`%4(G@"J"(X<20&^4&@('A!:"*X`.0B>!B4:#A`H`(X.(M
MBN`&H`'@!W")X`J@B.'`D!OE!8"&X0>@BN`#D(G@8G&@X0*`".#B+8K@!:`&
MX`$0B>`*H(CAO)`;Y0>`A>$!H(K@`Y")X&(1H.$"@`C@XBV*X`>@!>`&8(G@
M"J"(X;B0&^4!@(?A!J"*X`.0B>!B8:#A`H`(X.(MBN`!H`?@!5")X`J@B.&T
MD!OE!H"!X06@BN`#D(G@8E&@X0*`".#B+8K@!J`!X`=PB>`*H(CAL)`;Y06`
MAN$'H(K@`Y")X&)QH.$"@`C@XBV*X`6@!N`!$(G@"J"(X:R0&^4'@(7A`:"*
MX`.0B>!B$:#A`H`(X.(MBN`'H`7@!F")X`J@B.&HD!OE`8"'X0:@BN`#D(G@
M8F&@X0*`".#B+8K@`:`'X`50B>`*H(CAI)`;Y0:`@>$%H(K@`Y")X&)1H.$"
M@`C@XBV*X`:@`>`'<(G@"J"(X:"0&^4%@(;A!Z"*X`.0B>!B<:#A`H`(X.(M
MBN`%H`;@`1")X`J@B.&<D!OE!X"%X0&@BN`#D(G@8A&@X0*`".#B+8K@!Z`%
MX`9@B>`*H(CAF)`;Y0&`A^$&H(K@`Y")X&)AH.$"@`C@XBV*X`&@!^`%4(G@
M"J"(X920&^4&@('A!:"*X`.0B>!B4:#A`H`(X.(MBN`&H`'@!W")X`J@B.&0
MD!OE!8"&X0>@BN`#D(G@8G&@X0*`".#B+8K@!:`&X`$0B>`*H(CAC)`;Y0>`
MA>$!H(K@`Y")X&(1H.$"@`C@XBV*X`>@!>`&8(G@"J"(X8B0&^4!@(?A!J"*
MX`.0B>!B8:#A`H`(X.(MBN`!H`?@!9")X`J`B.$)@(C@A)`;Y090@>$#,(G@
M!W"#X`:0`>#T,I_E`E`%X("@&^7BC8C@"5"%X6(AH.%\D!OE!U"%X`-PBN`"
MH";@"*`JX`$0A^!H<:#AZ%V%X`H0@>`#@(G@>*`;Y0>0(N`%D"G@!H"(X&5A
MH.'E'8'@"8"(X`90)^`#D(K@=*`;Y>&-B.`"((G@`5`EX&$1H.%PD!OE!5""
MX`.@BN`!(";@!Z"*X`@@(N!H<:#AZ%V%X`(@BN`#@(G@;*`;Y0>0(>`%D"G@
M!F"(X&6!H.'E+8+@"6"&X`A0)^`#D(K@:*`;Y>)MAN`!$(G@`E`EX&(AH.%D
MD!OE!5"!X`.@BN`"$"C@!Z"*X`80(>!F<:#AYEV%X`$0BN`#8(G@8*`;Y0>0
M(N`%D"G@"&"&X&6!H.'E'8'@"6"&X`A0)^`#D(K@7*`;Y>%MAN`"((G@`5`E
MX&$1H.%8D!OE!5""X`.@BN`!("C@!Z"*X`8@(N!F<:#AYEV%X`(@BN`#8(G@
M5*`;Y0>0(>`%D"G@"&"&X&6!H.'E+8+@"6"&X`A0)^`#D(K@4*`;Y>)MAN`!
M$(G@`E`EX&(AH.%,D!OE!5"!X`.@BN`"$"C@!Z"*X`80(>!F<:#AYEV%X`$0
MBN`#8(G@2*`;Y0>0(N`(8(;@!8`IX&61H.'E'8'@"("&X`-@BN`)H"?@`B"&
MX`%@*N`&8(+@1"`;Y>%=B.!A$:#A`Z""X$"`&^4!("G@!Z"*X`4@(N!E<:#A
MY6V&X`(@BN`#4(C@/*`;Y0>`(>`&@"C@"5"%X&:1H.'F+8+@"%"%X`.@BN`)
M@"?@XFV%X`%0BN`"$"C@-*`;Y0$0A>`X4!OE8B&@X0.`A>`#,(K@`E`IX&:A
MH.'F'8'@!W"(X`0P@^`*@"+@!E`EX`&`*.`),(/@!5"'X.%=A>`(@(/@Y3V(
MX&$1C.!X01OE$,"0Y0`P@.4"((S@,#`;Y03`D.4`0)3E!5",X`K@CN`$`%/A
M"!"`Y1`@@.4$4(#E#."`Y0$``!HHT$OB\*^=Z#SU_^M(6`$`/`$``)EY@EJA
MZ]ENW+P;C];!8LH-P*#A8`"@XS#8+>D$L$SBK_7_ZP`@H.,L$)_E+$"?Y2S@
MG^4LP)_E`!"`Y2@0G^400(#I#,"`Y1`0@.44((#E&""`Y5P@@.4PJ)WH`2-%
M9XFKS>_^W+J8=E0R$/#ATL,-P*#A\-LMZ10PD.4"@*#A@B&@X0(PD^``(*#C
M`2"@(P!@H.$``%+C&""0Y5P`D.4!(((2J"Z"X```4.,$L$SB`4"@X1@@AN44
M,(;E')"&X@X```I`4&#B!0!8X0A0H+$``(G@!2"@X?WT_^M<,);E`S"%X$``
M4^-<,(;E\*N=&`8`H.$%@$C@!4"$X,/\_^L_`%CC&0``VD"`2.(H4Z#A`7"%
MX@=SA.`$$*#A"3"@X4`@A.(`0)'E!."1Y0C`D>4,`)'E$!"!X@(`4>$`0(/E
M!."#Y0C`@^4,`(/E$#"#XO/__QH!0*#A!@"@X:O\_^L'`%3AZ___&@5=9>`%
M@XC@!!"@X0D`H.$((*#AU/3_ZUR`AN7PJYWH#<"@X?#;+>D!0*#A?Q#@XQ1@
ME.4<@(3BIC&@X3\P`^(!((/B.`!2XP!0H.$8<)3E!+!,X@,0R.<"`(C@20``
MVD`@8N(`$*#CX/3_ZP0`H.&,_/_K"`"@X3@@H.,`$*#CVO3_ZR<\H.$F+*#A
M)PB@X2<4H.%;8,3E5##$Y28XH.$F9*#A50#$Y5DPQ.4$`*#A5W#$Y580Q.58
M(,3E6F#$Y7C\_^L#,-3E!`"@X0`PQ>6R,-3A`3#%Y0`PE.4C-*#A`C#%Y0`P
ME.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C-*#A!C#%Y00PE.4',,7E"S#4
MY0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@PE.4+,,7E#S#4Y0PPQ>6^,-3A
M#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4Y1`PQ>6R,=3A$3#%Y1`PE.4C
M-*#A$C#%Y1`PE.43,,7E)-!+XO!KG>A=]/_J."!BX@`0H..6]/_KNO__Z@W`
MH.$PV"WI8#"?Y6!`G^4#,(_@)"#3Y01`C^```%+C!+!,XC"HG1@!$*#C1""?
MY200P^4",)3G``!3XP(```HT,)_E`P"?YS'T_^LL,)_E`S"4YP``4^,PJ)T(
M(`"?Y0``C^`4T$OB,&B=Z)WT_^I`2P$`6$D!`!@!``"<2@$`3`$``%1#```\
M$)_E/#"?Y0$0C^``(-'E`S"/X```4N,>_R\1`0"@XR0@G^4``,'E`C"3YP``
M4^,>_R\!%`"?Y000@>(``(_@C_3_ZL!*`0#82`$`4`$``/!"```-P*#A\-@M
MZ02P3.(@T$WB'%*?Y1PRG^4%4(_@*``+Y2P0"^4P(`OE`T"5YS`@2^(`,)3E
M+!!+XB@`2^(@,`OE7/3_Z_`AG^7P,9_E`B"5YP,`E><"$*#A8O3_Z^`QG^4#
M,)7G`&#3Y0``5N-.```*T`&?Y0``C^"?]/_K`""0Y2A@&^4^,]+E!`"&X@,P
M@^,'`7#C/C/"Y0-@AN)8``"*``&@X3?T_^L`P*#A+#`;Y90AG^64$9_E``"3
MY0(@C^`$Q(+E`1"/X(0AG^4``(SE!!",Y0(0E><H(!OE``"1Y7`1G^4!`%+C
M`1"/X/@`S.$0$*#3"```V@3@0^("X8[@#!",X@0`L^4.`%/A!`"AY?O__QH#
M((+B`A&@X0#@H.,T49_E`>",YS`1G^4%4(_@!B"@X0P$E>4,,*#A`."-Y0$0
MC^`\]/_K`&!0XB@```H,49_E)'!+X@50C^`,!)7EY_/_Z_P`G^4'$*#A``"/
MX!?U_^L``%#C&```"N@PG^4#,(_@#`23Y<[S_^L8]/_K("`;Y0`PE.4&`*#A
M`P!2X2```!H<T$OB\*B=Z.#S_^NX,)_E``!0XP,PC^`,!(/E&0``"K/S_^ND
M`)_E``"/X$GT_^L`,)#EPV;#Y:/__^H(!)7E``!0XP8```IV^__KX?__Z@P$
ME>4G]/_K`&"@X=+__^H;]/_K:`"?Y0<0H.$``(_@[O3_ZP``4.,(!(7EU?__
M"O#__^JX\__K`0"@XW?S_^M\2`$`/`$``$@!``!8`0``*`$``$Q)`0#@20$`
M[`0``$0!``#,!```<$D!`-#;__]$20$`!`(``!Q)`0#D2`$`]$<!```!``!P
M<U]S=')I;F=S(&UI<W-I;F<*`'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@`````"X````N+@``)7,O)7,````O<')O8R]C
M=7)P<F]C+V5X90```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5`````!005)?5$5-4`````!005)?4%)/1TY!344`
M````.@```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]05```
M``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%
M04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'
M`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$
M7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R
M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C
M:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````
M&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4R
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````
M5$5-4$1)4@!435``+W1M<"\```!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%2
M7TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*
M;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M
M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N
M:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS
M92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE
M("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`[
M"G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@
M/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@
M+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL
M(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR
M96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A
M8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)$UO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@
M)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L
M(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@
M)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U
M<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL
M96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#
M*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE
M.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I
M*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@
M=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE
M<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@
M=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B
M=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*
M<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D
M9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B
M)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N
M(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C
M86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI.PHD
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*
M<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@
M)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X
M(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@
M<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C
M;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID
M96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@
M*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR
M971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B
M0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN
M8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@
M;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E
M;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T
M("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N
M;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D
M,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF
M("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```1L#
M._`````=````U)'__P@!```TDO__+`$``+R2__]4`0``;)3__[P!``!4E?__
MZ`$``/R5__\8`@``7)?__TP"``"4F?__A`(``"2:__^P`@``2)O__^0"``"P
MF___'`,``"B<__]$`P``,)S__U@#``"PGO__D`,``-B>__^D`P``+*#___0#
M``!<HO__)`0```2C__],!```)*/__VP$```8I/__H`0``-"K___8!```9*[_
M_PP%``#,KO__;`4``,RZ__^D!0``++O__\@%``!$O/__]`4``+R]__^,`0``
M1+[__W@!``"8OO__/`4``!```````````7I2``)\#@$;#`T`(````!@```#$
MD/__8`````!"#0Q(A`:%!8L$C0..`DH,"P0`)````#P`````D?__B`````!"
M#0Q*A`B%!X8&AP6+!(T#C@)&#`L$`"````!D````8)'__[`!````0@T,1(<%
MBP2-`XX"0@P+!````!````"(````Q+S__U0`````````+````)P````HO/__
MB`````!"#0Q$A`:%!8L$C0..`DP,"P1B#`T80L[-R\7$#@0`*````,P```"H
MDO__Z`````!"#0Q$A`J%"88(AP>(!HD%BP2-`XX"1`P+!``L````^````&23
M__^H`````$(-#$*$"(4'A@:'!8L$C0..`D(,"P0"1`H,#2!""P`P````*`$`
M`-R3__]@`0```$(-#$*$"X4*A@F'"(@'B0:*!8L$C0..`D(,"P1B"@P-+$(+
M-````%P!```(E?__.`(```!"#0Q"A`N%"H8)APB(!XD&B@6+!(T#C@)"#`L$
M`I@*#`TL0@L````H````E`$```B7__^0`````$(-#$*$!H4%BP2-`XX"0@P+
M!&X*#`T80@L``#````#``0``;)?__R0!````0@T,0H0*A0F&"(<'B`:)!8L$
MC0..`D(,"P0"7`H,#2A""P`T````]`$``%R8__]H`````$(-#$B$"(4'A@:'
M!8L$C0..`D(,"P1:#`T@0L[-R\?&Q<0.!````"0````L`@``C)C__W@`````
M0@T,1(0&A06+!(T#C@)$#`L$9@P-&``0````5`(``-R8__\(`````````#0`
M``!H`@``T)C__X`"````0@T,0H0+A0J&"8<(B`>)!HH%BP2-`XX"1`P+!`)"
M"@P-+$(+````$````*`"```8F___*`````````!,````M`(``"R;__]4`0``
M`$(-#$*$!H4%BP2-`XX"1`P+!'@*#`T80L[-R\7$#@1""T8*#`T80L[-R\7$
M#@1""P)0#`T80L[-R\7$#@0``"P````$`P``,)S__S`"````0@T,0H0'A0:&
M!8L$C0..`D(,"P0"L`H,#1Q""P```"0````T`P``,)[__Z@`````0@T,0H0%
MBP2-`XX"0@P+!&(*#`T40@L<````7`,``+">__\@`````$(-#$*+!(T#C@)"
M#`L$`#````!\`P``L)[___0`````0@T,0H0)A0B&!X<&B`6+!(T#C@)"#`L$
M`F0*#`TD0@L````T````L`,``'"?__^X!P```$(-#$*$"X4*A@F'"(@'B0:*
M!8L$C0..`D0,"P0#9@$*#`TL0@L``#````#H`P``\*;__Y0"````0@T,0H0)
MA0B&!X<&B`6+!(T#C@)"#`L$`MH*#`TD0@L````L````'`0``%"I__]H````
M`$(-#$*$!H4%BP2-`XX"0@P+!&@,#1A"SLW+Q<0.!``L````3`0``%2Y__]\
M`@```$(-#$*$"(4'A@:'!8L$C0..`D(,"P0"S@H,#2!""P`T````?`0``%BI
M__\`#````$(-#$*$"X4*A@F'"(@'B0:*!8L$C0..`D(,"P0#Z@4*#`TL0@L`
M`"````"T!```(+7__V``````0@T,1(0&A06+!(T#C@)"#`L$`"@```#8!```
M7+7__Q@!````0@T,1(0*A0F&"(<'B`:)!8L$C0..`EH,"P0`/`````0%``!(
MMO__>`$```!"#0Q"A`J%"88(AP>(!HD%BP2-`XX"5@P+!`*6"@P-*$+.S<O)
MR,?&Q<0.!$(+``````#X0@``<$(````````!`````0````$```#!`@```0``
M`,L"```!````V0(```$```#_`@``#P```)D$```9````[(H!`!L````$````
M&@```/"*`0`<````!`````0```!X`0``!0```#@+```&````J`0```H```#B
M!```"P```!`````5``````````,```#HBP$``@```!`"```4````$0```!<`
M```\$0``$0```!P0```2````(`$``!,````(````^___;P````CZ__]O&0``
M``````````````````````````````````````````````````````#XB@$`
M``````````!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,
M$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3
M``!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,`
M`$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``
M3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,
M$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3``!,$P``3!,``$P3
M``#TB@$``````"P1````````[(H!``````````````````"2`0`L$0``````
M`/"*`0"0C0$`````````````````^(H!``````#$C0$``````%2-`0"$,```
MP(T!`%B-`0#_____+$D```Q&````````'$<``"!'```@20``:$8``"A)````
M````#$D``!1)````````-$D``$=#0SH@*$YE=$)31"!N8C0@,C`R,#`X,3`I
M(#<N-2XP`$=#0SH@*&YB-"`R,#(P,#@Q,"D@-RXU+C``)$YE=$)31#H@8W)T
M,"Y3+'8@,2XT(#(P,3@O,3$O,C8@,3<Z,S<Z-#0@:F]E<F<@17AP("0`)$YE
M=$)31#H@8W)T,"UC;VUM;VXN8RQV(#$N,C,@,C`Q."\Q,B\R."`R,#HQ,CHS
M-2!C:')I<W1O<R!%>'`@)``D3F5T0E-$.B!C<G1I+E,L=B`Q+C$@,C`Q,B\P
M."\Q,R`P,CHT.3HP-"!M871T($5X<"`D`"1.971"4T0Z(&-R=&)E9VEN+F,L
M=B`Q+C$W(#(P,3@O,3(O,C@@,3@Z,3<Z,3$@8VAR:7-T;W,@17AP("0`)$YE
M=$)31#H@8W)T96YD+E,L=B`Q+C(@,C`Q,R\Q,B\R,"`Q-3HS-3HT."!J;V5R
M9R!%>'`@)`````#QSP(`````````````````"`````@````(````"````!L`
M```!```````````J*BH@3F\@3&%B96P@4')O=FED960@*BHJ``#QSP(`````
M````````````"`````@````(````"````!L````!```````````J*BH@3F\@
M3&%B96P@4')O=FED960@*BHJ`$$W````865A8FD``2T````%05)-,3$W-DI:
M1BU3``8'"`$)`0H"$@04`14!%P,8`1H"'`$B`40!`"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+FYE=&)S9"YI9&5N=``N;F]T92YN971B<V0N<&%X`"YN;W1E
M+FYE=&)S9"YM87)C:``N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`
M+G)E;"YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`
M+F1A=&$`+F)S<P`N8V]M;65N=``N4U5.5U]C=&8`+D%232YA='1R:6)U=&5S
M```````````````````````````````````````````````````````+````
M`0````(````4`0``%`$``!<```````````````$`````````$P````<````"
M````+`$``"P!```8```````````````$`````````"8````'`````@```$0!
M``!$`0``%```````````````!``````````W````!P````(```!8`0``6`$`
M`"````````````````0`````````2@````4````"````>`$``'@!```P`P``
M!@`````````$````!````%`````+`````@```*@$``"H!```D`8```<````#
M````!````!````!8`````P````(````X"P``.`L``.($``````````````$`
M````````8`````D````"````'!```!P0```@`0``!@`````````$````"```
M`&D````)````0@```#P1```\$0``$`(```8````3````!`````@```!M````
M`0````8```!,$P``3!,``"P#``````````````0````$````<@````$````&
M````>!8``'@6``!0+P`````````````$`````````'@````!`````@```,A%
M``#(10``[#X`````````````!`````````"``````0````(```"TA```M(0`
M`/0```````````````0`````````C@````$````"````J(4``*B%``!$!0``
M```````````$`````````)@````.`````P```.R*`0#LB@``!```````````
M````!`````0```"D````#P````,```#PB@$`\(H```0```````````````0`
M```$````L`````$````#````](H!`/2*```$```````````````$````````
M`+4````&`````P```/B*`0#XB@``\`````<`````````!`````@```"^````
M`0````,```#HBP$`Z(L``&P!``````````````0````$````PP````$````#
M````5(T!`%2-``!````````````````$`````````,D````(`````P```,"-
M`0"4C0``1`0`````````````0`````````#.`````0```#``````````E(T`
M`#L```````````````$````!````'P````$``````````````,^-```B`0``
M```````````!`````````-<````!``````````````#TC@``CP``````````
M````!`````````#A`````P``<```````````@X\``#@```````````````$`
M`````````0````,``````````````+N/``#Q```````````````!````````
!````
